pub struct ModalityLayer { /* private fields */ }Expand description
A tracing Layer that can be used to record trace events and stream them to modality in real
time.
Can be transformed into a Subscriber with ModalityLayer::into_subscriber().
Implementations
Sourceimpl ModalityLayer
impl ModalityLayer
Sourcepub async fn init() -> Result<(Self, ModalityIngestTaskHandle), InitError>
pub async fn init() -> Result<(Self, ModalityIngestTaskHandle), InitError>
Initialize a new ModalityLayer, with default options.
Sourcepub async fn init_with_options(
opts: Options,
) -> Result<(Self, ModalityIngestTaskHandle), InitError>
pub async fn init_with_options( opts: Options, ) -> Result<(Self, ModalityIngestTaskHandle), InitError>
Initialize a new ModalityLayer, with specified options.
Sourcepub fn into_subscriber(self) -> impl Subscriber
pub fn into_subscriber(self) -> impl Subscriber
Convert this Layer into a Subscriberby by layering it on a new instace of tracing’s
Registry.